@@ -1,7 +1,10 @@
-import requests
-from keen import exceptions
 import json
 
+import requests
+
+from keen import exceptions
+
+
 __author__ = 'dkador'
 
 
@@ -16,6 +19,8 @@ class KeenApi(object):
     # the default version of the Keen API
     api_version = "3.0"
 
+    # self says it belongs to KeenApi/andOr is the object passed into KeenApi
+    # __init__ create keenapi object whenever KeenApi class is invoked
     def __init__(self, project_id,
                  write_key=None, read_key=None,
                  base_url=None, api_version=None):
@@ -30,6 +35,7 @@ class KeenApi(object):
         :param api_version: string, optional, set this to override what API
         version is used
         """
+        # super? recreates the object with values passed into KeenApi
         super(KeenApi, self).__init__()
         self.project_id = project_id
         self.write_key = write_key
@@ -46,9 +52,11 @@ class KeenApi(object):
         :param event: an Event to upload
         """
         if not self.write_key:
-            raise Exception("The Keen IO API requires a write key to send events. "
-                            "Please set a 'write_key' when initializing the "
-                            "KeenApi object.")
+            raise exceptions.InvalidEnvironmentError(
+                "The Keen IO API requires a write key to send events. "
+                "Please set a 'write_key' when initializing the "
+                "KeenApi object."
+            )
 
         url = "{0}/{1}/projects/{2}/events/{3}".format(self.base_url, self.api_version,
                                                        self.project_id,
@@ -60,15 +68,40 @@ class KeenApi(object):
             error = response.json()
             raise exceptions.KeenApiError(error)
 
+    def post_events(self, events):
+
+        """
+        Posts a single event to the Keen IO API. The write key must be set first.
+
+        :param events: an Event to upload
+        """
+        if not self.write_key:
+            raise exceptions.InvalidEnvironmentError(
+                "The Keen IO API requires a write key to send events. "
+                "Please set a 'write_key' when initializing the "
+                "KeenApi object."
+            )
+
+        url = "{0}/{1}/projects/{2}/events".format(self.base_url, self.api_version,
+                                                   self.project_id)
+        headers = {"Content-Type": "application/json", "Authorization": self.write_key}
+        payload = json.dumps(events)
+        response = requests.post(url, data=payload, headers=headers)
+        if response.status_code != 200:
+            error = response.json()
+            raise exceptions.KeenApiError(error)
+
     def query(self, analysis_type, params):
         """
         Performs a query using the Keen IO analysis API.  A read key must be set first.
 
         """
         if not self.read_key:
-            raise Exception("The Keen IO API requires a read key to perform queries. "
-                            "Please set a 'read_key' when initializing the "
-                            "KeenApi object.")
+            raise exceptions.InvalidEnvironmentError(
+                "The Keen IO API requires a read key to perform queries. "
+                "Please set a 'read_key' when initializing the "
+                "KeenApi object."
+            )
 
         url = "{0}/{1}/projects/{2}/queries/{3}".format(self.base_url, self.api_version,
                                                         self.project_id, analysis_type)
@@ -80,4 +113,4 @@ class KeenApi(object):
             error = response.json()
             raise exceptions.KeenApiError(error)
 
-        return response.json()["result"]
\ No newline at end of file
+        return response.json()["result"]
